clear all,clc, close all

addpath('0_bibinov_data')

load Output/HeO2plug/chamber_position.mat
load Output/HeO2plug/chamber_speciesDensities.mat

[x_e_exp,n_e_exp] = importfile('0_bibinov_data/meas_fig8_elec.txt');
[x_O_exp,n_O_exp] = importfile('0_bibinov_data/meas_fig9.txt');
[x_O3_exp,n_O3_exp] = importfile('0_bibinov_data/meas_fig10.txt');

Simulation_length = chamber_position;
Simulation_n_O = n_density(:,6);
Simulation_n_O3 = n_density(:,8);
Simulation_n_e = n_density(:,18);



figure(1)
scale_O = 1e22;
m1=plot(x_O_exp*1e3,n_O_exp./scale_O,'s','Color','r','MarkerSize',10);
set(m1, 'markerfacecolor', get(m1, 'color'));
hold on

load Output/HeO2/speciesDensities.mat
n_O_length = 1:40;
n_O = (zeros(1,40) + 1).*n_density(end,6);
hold on
plot(n_O_length,n_O./scale_O,'-','Color','k','LineWidth',2)

h1=plot(Simulation_length*1e3,Simulation_n_O./scale_O,'--','Color','b','LineWidth',2);

h2 = line([40 40],[0 3e22./scale_O]);
% Set properties of lines
set([h2],'Color','k','LineWidth',1,'LineStyle','-.')
x1 = 40;
x2 = 50;
fx = [40 50 50 40 40];
Ys = ylim;
fy = [Ys(1) Ys(1) Ys(2) Ys(2) Ys(1)];
fill( fx,fy, [0 0 0], 'FaceAlpha', 0.15,'LineStyle','none');
hold off

set(h1, 'markerfacecolor', get(h1, 'color'));
xlim([0 50])
xticks(0:5:50)
xlabel('Length (mm)')
ylim([0 3e22./scale_O])
ylabel('O(^3P) density (10^{22} m^{-3})')

ax1 = gca;    % current axes
set(ax1,'FontSize',15)
ax1_pos = ax1.Position;   % position of first axes
lgd1 = legend(ax1,{'Meas.','Sim.(0-D)','Sim.(plug-flow)'});    %,'Location','northwest')
lgd1.FontSize = 15;

text(15,2e22./scale_O,'Plasma Jet','Color',[0 0.5 0],'FontSize',16)
text(40,2e22./scale_O,'Effluent','Color',[0 0.5 0],'FontSize',16)

set(gcf,'position',[100,100,600,450])

text(0.05,0.95,'(a)','Units','normalized','Color','k','FontSize',15)

% saveas(figure(1),'/home/he/1_PhD/phd/Meeting/Bochum/InternationalOnlinePlasmaSeminar/2020-12-03/figure/Bib11_1.png');




figure(2)
scale_O3 = 1e21;
m2=plot(x_O3_exp*1e3,n_O3_exp./scale_O3,'o','Color','r','MarkerSize',10);
set(m2, 'markerfacecolor', get(m2, 'color'));
hold on

load Output/HeO2/speciesDensities.mat
n_O3_length = 1:40;
n_O3 = (zeros(1,40) + 1).*n_density(end,8);
hold on
plot(n_O3_length,n_O3./scale_O3,'-','Color','k','LineWidth',2)

h1=plot(Simulation_length*1e3,Simulation_n_O3./scale_O3,'--','Color','b','LineWidth',2);

h2 = line([40 40],[0 9e21./scale_O3]);
% Set properties of lines
set([h2],'Color','k','LineWidth',1,'LineStyle','-.')
x1 = 40;
x2 = 50;
fx = [40 50 50 40 40];
Ys = ylim;
fy = [Ys(1) Ys(1) Ys(2) Ys(2) Ys(1)];
fill( fx,fy, [0 0 0], 'FaceAlpha', 0.15,'LineStyle','none');
hold off

set(h1, 'markerfacecolor', get(h1, 'color'));
xlim([0 50])
xticks(0:5:50)
xlabel('Length (mm)')
ylim([0 9e21./scale_O3])
ylabel('O_3 density (10^{21} m^{-3})')

ax1 = gca;    % current axes
set(ax1,'FontSize',15)
ax1_pos = ax1.Position;   % position of first axes
lgd1 = legend(ax1,{'Meas.','Sim.(0-D)','Sim.(plug-flow)'});    %,'Location','northwest')
lgd1.FontSize = 15;

text(15,0.6e22./scale_O3,'Plasma Jet','Color',[0 0.5 0],'FontSize',16)
text(40,0.6e22./scale_O3,'Effluent','Color',[0 0.5 0],'FontSize',16)

set(gcf,'position',[100,100,600,450])

text(0.05,0.95,'(b)','Units','normalized','Color','k','FontSize',15)

% saveas(figure(2),'/home/he/1_PhD/phd/Meeting/Bochum/InternationalOnlinePlasmaSeminar/2020-12-03/figure/Bib11_2.png');



figure(3)
scale_e = 1e16;
m3=plot(x_e_exp*1e3,n_e_exp./scale_e,'^','Color','r','MarkerSize',10);
set(m3, 'markerfacecolor', get(m3, 'color'));
hold on

load Output/HeO2/speciesDensities.mat
n_e_length = 1:40;
n_e = (zeros(1,40) + 1).*n_density(end,18);
hold on
plot(n_e_length,n_e./scale_e,'-','Color','k','LineWidth',2)

h1=plot(Simulation_length*1e3,Simulation_n_e./scale_e,'--','Color','b','LineWidth',2);

h2 = line([40 40],[0 15e16./scale_e]);
% Set properties of lines
set([h2],'Color','k','LineWidth',1,'LineStyle','-.')
x1 = 40;
x2 = 50;
fx = [40 50 50 40 40];
Ys = ylim;
fy = [Ys(1) Ys(1) Ys(2) Ys(2) Ys(1)];
fill( fx,fy, [0 0 0], 'FaceAlpha', 0.15,'LineStyle','none');
hold off

set(h1, 'markerfacecolor', get(h1, 'color'));
xlim([0 50])
xticks(0:5:50)
xlabel('Length (mm)')
ylim([0 15e16./scale_e])
ylabel('Electron density (10^{16} m^{-3})')

ax1 = gca;    % current axes
set(ax1,'FontSize',15)
ax1_pos = ax1.Position;   % position of first axes
lgd1 = legend(ax1,{'Meas.','Sim.(0-D)','Sim.(plug-flow)'});    %,'Location','northwest')
lgd1.FontSize = 15;

text(15,1e17./scale_e,'Plasma Jet','Color',[0 0.5 0],'FontSize',16)
text(40,1e17./scale_e,'Effluent','Color',[0 0.5 0],'FontSize',16)

set(gcf,'position',[100,100,600,450])

text(0.05,0.95,'(c)','Units','normalized','Color','k','FontSize',15)

% saveas(figure(3),'/home/he/1_PhD/phd/Meeting/Bochum/InternationalOnlinePlasmaSeminar/2020-12-03/figure/Bib11_3.png');


